@@ -49,6 +49,7 @@
 
 package com.openexchange.halo.pictures;
 
+import javax.servlet.http.HttpServletResponse;
 import com.openexchange.ajax.container.ByteArrayFileHolder;
 import com.openexchange.ajax.requesthandler.AJAXRequestData;
 import com.openexchange.ajax.requesthandler.AJAXRequestResult;
@@ -58,6 +59,7 @@ import com.openexchange.exception.OXException;
 import com.openexchange.groupware.container.Contact;
 import com.openexchange.halo.ContactHalo;
 import com.openexchange.halo.Picture;
+import com.openexchange.java.Strings;
 import com.openexchange.server.ServiceExceptionCode;
 import com.openexchange.server.ServiceLookup;
 import com.openexchange.tools.servlet.http.Tools;
@@ -85,7 +87,7 @@ public class GetPictureAction implements ETagAwareAJAXActionService {
         if (picture == null) {
             // 404 - Not Found
             AJAXRequestResult result = new AJAXRequestResult();
-            result.setHttpStatusCode(404);
+            result.setHttpStatusCode(HttpServletResponse.SC_NOT_FOUND);
             return result;
         }
         AJAXRequestResult result = new AJAXRequestResult(picture.getFileHolder(), "file");
@@ -145,7 +147,11 @@ public class GetPictureAction implements ETagAwareAJAXActionService {
         }
 
         if (req.isSet("id") && !hadCriterium) {
-            contact.setObjectID(req.getIntParameter("id"));
+            int id = Strings.parsePositiveInt(req.getParameter("id"));
+            if (id > 0) {
+                contact.setObjectID(req.getIntParameter("id"));
+            }
+
             if (req.isSet("folder")) {
                 hadCriterium = true;
                 contact.setParentFolderID(req.getIntParameter("folder"));
